@@ -1,7 +1,7 @@
 from pysecure import log_config
 from pysecure.easy import connect_ssh_with_cb, connect_sftp_with_cb, \
                           get_key_auth_cb
-from pysecure.test.test_config import user, host, key_filepath, verbosity
+from test.test_config import user, host, key_filepath, verbosity
 
 def connect_sftp_test(sftp_cb):
     auth_cb = get_key_auth_cb(key_filepath)
